intelmq.bots.outputs.file package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.outputs.file package

## Submodules

## intelmq.bots.outputs.file.output module

intelmq.bots.outputs.file.output.BOT

  alias of `intelmq.bots.outputs.file.output.FileOutputBot`

class intelmq.bots.outputs.file.output.FileOutputBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  Write events to a file

  static check(parameters)

    The bot’s own check function can perform individual checks on it’s parameters. init() is not called before, this is a staticmethod which does not require class initialization.

    Parameters

      parameters – Bot’s parameters, defaults and runtime merged together

    Returns

      None or a list of [log_level, log_message] pairs, both

        strings. log_level must be a valid log level.

    Return type

      output

  encoding_errors_mode = 'strict'
  file: str = '/opt/intelmq/var/lib/bots/file-output/events.txt'
  format_filename: bool = False
  hierarchical_output: bool = False
  init()
  keep_raw_field: bool = False
  message_jsondict_as_string: bool = False
  message_with_type: bool = False
  open_file(filename: Optional[str] = None)
  process()
  shutdown()
  single_key: bool = False

## Module contents